summaryrefslogtreecommitdiff
path: root/usr.bin
diff options
context:
space:
mode:
authorJoseph Koshy <jkoshy@FreeBSD.org>1998-05-22 09:38:23 +0000
committerJoseph Koshy <jkoshy@FreeBSD.org>1998-05-22 09:38:23 +0000
commitb610f0484cd6e2ffc62486059a2b38a76ad1e30d (patch)
tree92e1654bd228924cb058130d8b5309c1045210f0 /usr.bin
parent13bb7b9673ae41b9fd739f2c86552f2c411adee4 (diff)
Notes
Diffstat (limited to 'usr.bin')
-rw-r--r--usr.bin/passwd/local_passwd.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/usr.bin/passwd/local_passwd.c b/usr.bin/passwd/local_passwd.c
index b3673926cdfc..8f023e395c11 100644
--- a/usr.bin/passwd/local_passwd.c
+++ b/usr.bin/passwd/local_passwd.c
@@ -30,7 +30,7 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * $Id: local_passwd.c,v 1.9.2.3 1998/03/07 21:44:00 ache Exp $
+ * $Id: local_passwd.c,v 1.9.2.4 1998/03/08 12:04:07 jkh Exp $
*/
#ifndef lint
@@ -120,8 +120,8 @@ getnewpasswd(pw, nis)
/* minpasswordlen capablity */
min_length = (int)login_getcapnum(lc, "minpasswordlen",
min_length, min_length);
- /* passwordperiod capability */
- period = login_getcaptime(lc, "passwordperiod", 0, 0);
+ /* passwordtime capability */
+ period = login_getcaptime(lc, "passwordtime", 0, 0);
if (period > (time_t)0) {
pw->pw_change = time(NULL) + period;
}
@@ -204,7 +204,7 @@ local_passwd(uname)
* Get the new password. Reset passwd change time to zero by
* default. If the user has a valid login class (or the default
* fallback exists), then the next password change date is set
* by getnewpasswd() according to the "passwordperiod" capability
* if one has been specified.
*/
pw->pw_change = 0;
@@ -204,7 +204,7 @@ local_passwd(uname)
* default. If the user has a valid login class (or the default
* fallback exists), then the next password change date is set
- * by getnewpasswd() according to the "passwordperiod" capability
+ * by getnewpasswd() according to the "passwordtime" capability
* if one has been specified.
*/